@@ -1,8 +1,8 @@
-__title__ = 'Amino.py'
+__title__ = 'Amino_new.py'
 __author__ = 'Slimakoi'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2021 Slimakoi'
-__version__ = '1.2.17'
+__version__ = '3.3'
 
 from .acm import ACM
 from .client import Client
